package net.wanji.opt.common.enums;

public enum StrategyEnum {
    NO_STRATEGY(0, "无策略"),
    GREEN_LIGHT_IDLE(1, "绿灯空放"),
    IMBALANCE(2, "失衡"),
    OVERFLOW(3, "溢出"),
    CONGESTION(4, "拥堵");

    // 策略编号
    private final int code;
    // 策略名称
    private final String name;

    /**
     * 构造函数
     *
     * @param code 策略编号
     * @param name 策略名称
     */
    StrategyEnum(int code, String name) {
        this.code = code;
        this.name = name;
    }

    /**
     * 获取策略编号
     *
     * @return 策略编号
     */
    public int getCode() {
        return code;
    }

    /**
     * 获取策略名称
     *
     * @return 策略名称
     */
    public String getName() {
        return name;
    }

    /**
     * 根据编号获取对应的枚举实例
     *
     * @param code 策略编号
     * @return 对应的枚举实例，如果未找到则返回 null
     */
    public static StrategyEnum fromCode(int code) {
        for (StrategyEnum strategy : values()) {
            if (strategy.getCode() == code) {
                return strategy;
            }
        }
        return null; // 或者抛出异常：throw new IllegalArgumentException("未知的策略编号: " + code);
    }

    /**
     * 根据名称获取对应的枚举实例
     *
     * @param name 策略名称
     * @return 对应的枚举实例，如果未找到则返回 null
     */
    public static StrategyEnum fromName(String name) {
        for (StrategyEnum strategy : values()) {
            if (strategy.getName().equals(name)) {
                return strategy;
            }
        }
        return null; // 或者抛出异常：throw new IllegalArgumentException("未知的策略名称: " + name);
    }

    /**
     * 覆盖 toString 方法，方便打印枚举信息
     *
     * @return 枚举的字符串表示
     */
    @Override
    public String toString() {
        return String.format("StrategyEnum[code=%d, name=%s]", code, name);
    }
}