package net.wanji.opt.controllerv2.report.design;

import com.alibaba.fastjson.JSON;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.ParentResult;

import java.util.ArrayList;
import java.util.List;

@Data
public class AreaCrossRunStateDayAnalysisResult extends ParentResult {

    private AreaCrossRunStateDayAnalysisResultResponse content;

    public AreaCrossRunStateDayAnalysisResultResponse getContent() {
        return content;
    }

    public AreaCrossRunStateDayAnalysisResult setContent(AreaCrossRunStateDayAnalysisResultResponse content) {
        this.content = content;
        return this;
    }

    @Override
    public String toString() {
        return JSON.toJSONString(this);
    }

}

@Data
class AreaCrossRunStateDayAnalysisResultResponse {

    @ApiModelProperty(value = "早高峰流量与上周比较情况", example = "上升",position = 0)
    private String amFlowCompareSituation;

    @ApiModelProperty(value = "本周当日指标与上周环比情况",position = 1)
    private List<AreaCrossRunStateDayAnalysisData> dataList = new ArrayList<>();

    @ApiModelProperty(value = "区域早高峰最拥堵路口名称", example = "经十路（舜耕路-山大路）",position = 2)
    private String amMostCongestCrossName;
    @ApiModelProperty(value = "区域早高峰最拥堵路口交通指数", example = "3.5",position = 3)
    private String amMostCongestIndex;

    @ApiModelProperty(value = "区域晚高峰最拥堵路口名称", example = "经十路（舜耕路-山大路）",position = 4)
    private String pmMostCongestCrossName;
    @ApiModelProperty(value = "区域晚高峰最拥堵路口交通指数", example = "3.5",position = 5)
    private String pmMostCongestIndex;

    @ApiModelProperty(value = "日综合效率最低路口名称", example = "经十路（舜耕路-山大路）",position = 6)
    private String dayLowestEfficiencyCrossName;
    @ApiModelProperty(value = "日综合效率最低路口-交通指数", example = "3.5",position = 7)
    private String dayLowestEfficiencyIndex;

    @ApiModelProperty(value = "区域内路口运行情况总体排名",position = 8)
    private List<AreaCrossRunRankData> dayRankList = new ArrayList<>();

    @ApiModelProperty(value = "区域内路口早高峰运行情况排名",position = 9)
    private List<AreaCrossRunRankData> amRankList = new ArrayList<>();

    @ApiModelProperty(value = "区域内路口晚高峰运行情况排名",position = 10)
    private List<AreaCrossRunRankData> pmRankList = new ArrayList<>();

    @ApiModelProperty(value = "当时拥堵与上周比较情况", example = "上升",position = 11)
    private String dayCongestCompareSituation;

    @ApiModelProperty(value = "区域内路口总体交通指数较上周变化情况", position = 12)
    AreaCrossTrafficIndexTrend trafficIndexChange = new AreaCrossTrafficIndexTrend();

}

@Data
class AreaCrossRunStateDayAnalysisData {

    @ApiModelProperty(value = "峰期名称", example = "早高峰/晚高峰",position = 1)
    private String peakName;

    @ApiModelProperty(value = "本周当日峰期总流量", example = "40",position = 2)
    private Integer flow;
    @ApiModelProperty(value = "本周当日峰期总流量同比情况【正数上升，负数下降】", example = "-0.7",position = 3)
    private Double flowCompareRatio;

    @ApiModelProperty(value = "本周当日峰期交通指数", example = "4.0",position = 4)
    private Double trafficIndex;
    @ApiModelProperty(value = "本周当日峰期交通指数同比情况【正数上升，负数下降】", example = "-0.7",position = 5)
    private Double trafficIndexCompareRatio;

    @ApiModelProperty(value = "本周当日平均车速", example = "35.5",position = 6)
    private Double speed;
    @ApiModelProperty(value = "本周当日峰期平均车上同比情况【正数上升，负数下降】", example = "4.5",position = 7)
    private Double speedCompareRatio;

}

@Data
class AreaCrossRunRankData {

    @ApiModelProperty(value = "路口名称", example = "舜耕路-山大路",position = 2)
    private String crossName;

    @ApiModelProperty(value = "交通指数", example = "3.1",position = 3)
    private Double trafficIndex;

    @ApiModelProperty(value = "排名", example = "1",position = 4)
    private Integer rank;

}


@Data
class AreaCrossTrafficIndexTrend {

    @ApiModelProperty(value = "时段列表（小时/分钟）粒度格式：HH:mm",example = "[\"01:00\",\"02:00\"]",dataType = "String[]")
    private   List<String> timeList = new ArrayList<>();


    @ApiModelProperty(value = "本周当日所有路口平均交通指数", example = "[3.2,2.5]",position = 2)
    private List<Double> thisList = new ArrayList<>();

    @ApiModelProperty(value = "上周当日所有路口平均交通指数", example = "[3.2,2.5]",position = 2)
    private List<Double> lastList = new ArrayList<>();

}
