package net.wanji.opt.servicev2.strategy.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.nacos.common.utils.CollectionUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.utils.tool.StringUtils;
import net.wanji.opt.common.exception.OptServiceException;
import net.wanji.opt.dao.mapper.strategy.StrategyPriorityMapper;
import net.wanji.opt.entity.strategy.*;
import net.wanji.opt.entity.strategy.dto.StrategyPriorityGroupVO;
import net.wanji.opt.servicev2.strategy.StrategyPriorityService;
import net.wanji.opt.synthesis.pojo.Result;
import net.wanji.opt.synthesis.pojo.StrategyFactoryEntity;
import net.wanji.opt.synthesis.service.PushStrategyControlService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;

/**
 * <p>
 * 策略优先级日计划详情表 服务实现类
 * </p>
 *
 * @author fengyi
 * @since 2025-03-28
 */
@Service
@Slf4j
@SuppressWarnings("all")
public class StrategyPriorityServiceImpl extends ServiceImpl<StrategyPriorityMapper, StrategyPriorityDailyInfo> implements StrategyPriorityService {

    @Resource
    private StrategyPriorityMapper strategyPriorityMapper;

    @Resource
    private PushStrategyControlService pushStrategyControlService;

    /**
     * 策略路口列表
     *
     * @param
     * @return
     */
    @Override
    public List<StrategyPriorityDailyInfo> pageStrategyCrossList() {
        List<StrategyPriorityDailyInfo> allList = strategyPriorityMapper.pageStrategyCrossList();

        return allList;
    }

    /**
     * 策略名称
     *
     * @param
     * @return
     */
    @Override
    public List<StrategyFactoryEntity> getStrategyList() {
        List<StrategyFactoryEntity> strategyList = strategyPriorityMapper.getStrategyList();
        return strategyList;
    }

    /**
     * 场景
     *
     * @param
     * @return
     */
    @Override
    public List<StrategyFactoryEntity> getSceneList(Integer type) {

        List<StrategyFactoryEntity> strategyList = strategyPriorityMapper.getSceneList(type);
        return strategyList;
    }

    /**
     * 厂商
     *
     * @param
     * @return
     */
    @Override
    public List<StrategyFactoryEntity> getCompanyList() {
        List<StrategyFactoryEntity> strategyList = strategyPriorityMapper.getCompanyList();
        return strategyList;
    }

    /**
     * 策略优先级保存 路口 干线共用
     *
     * @param dataList
     * @throws Exception
     */
    @Override
    @Transactional
    public void savePriority(List<StrategyPriorityGroupVO> dataList) throws Exception {
        try {
            List<StrategyPriorityConfig> saveList = new ArrayList<>();
            for (StrategyPriorityGroupVO group : dataList) {
                //Type : 1;路口2：干线
                Integer typePd = group.getType();
                if (typePd == 1) {
                    String groupName = group.getGroupName();
                    Integer groupId = group.getGroupId();
                    //1；路口2干线
                    Integer type = group.getType();
                    //路口id
                    List<String> crossList = group.getCrossIds();
                    //选中多个路口存多条数据
                    for (String crossId : crossList) {
                        //先判断表里有没有数据，有的话删除t_strategy_priority_config
                        List<StrategyPriorityConfig> priorityConfig = strategyPriorityMapper.selectPriorityTable(crossId);
                        if (priorityConfig.size() > 0) {
                            strategyPriorityMapper.deletePriorityConfig(crossId);
                        }

                        if (CollectionUtils.isNotEmpty(group.getData())) {
                            for (StrategyPriorityConfig item : group.getData()) {
                                StrategyPriorityConfig strategyPriorityConfig = new StrategyPriorityConfig();
                                strategyPriorityConfig.setCrossId(crossId);
                                //分组id
                                strategyPriorityConfig.setGroupId(groupId);
                                //分组名称
                                strategyPriorityConfig.setGroupName(groupName);
                                //策略编号
                                strategyPriorityConfig.setStrategyNo(item.getStrategyNo());
                                //优先级
                                strategyPriorityConfig.setPriority(item.getPriority());
                                //type
                                strategyPriorityConfig.setType(type);
                                saveList.add(strategyPriorityConfig);
                            }
                        }
                    }
                } else if (typePd == 2) {
                    String label = group.getGroupName();
                    Integer labelCode = group.getGroupId();
                    //1；路口2干线
                    Integer type = group.getType();
                    //干线id
                    List<Integer> greenList = group.getGreenIds();
                    //选中多个干线存多条数据
                    for (Integer greenId : greenList) {
                        //先判断表里有没有数据，有的话删除t_strategy_priority_config
                        List<StrategyPriorityConfig> priorityConfig = strategyPriorityMapper.selectGreenPriorityTable(greenId);
                        if (priorityConfig.size() > 0) {
                            strategyPriorityMapper.deleteGreenPriorityConfig(greenId);
                        }

                        if (CollectionUtils.isNotEmpty(group.getData())) {
                            for (StrategyPriorityConfig item : group.getData()) {
                                StrategyPriorityConfig strategyPriorityConfig = new StrategyPriorityConfig();
                                //干线id
                                strategyPriorityConfig.setGreenId(greenId);
                                //分组id
                                strategyPriorityConfig.setGroupId(labelCode);
                                //分组名称
                                strategyPriorityConfig.setGroupName(label);
                                //策略编号
                                strategyPriorityConfig.setStrategyNo(item.getStrategyNo());
                                //优先级
                                strategyPriorityConfig.setPriority(item.getPriority());
                                //type
                                strategyPriorityConfig.setType(type);
                                saveList.add(strategyPriorityConfig);
                            }
                        }
                    }
                }
            }
            strategyPriorityMapper.savePriorityInsert(saveList);

            //最终优先级配置推送神思
            List<StrategyPriorityConfigPush> pushStrategyPriorityList = pushStrategyPriorityConfig(dataList);
            //调用推送接口
            StrategyPriorityGroupPushReq strategyPriorityGroupPushReq = new StrategyPriorityGroupPushReq();
            strategyPriorityGroupPushReq.setData(pushStrategyPriorityList);
            Result result = pushStrategyControlService.StartegyPriorityPush(strategyPriorityGroupPushReq);
        } catch (Exception e) {
            log.error("{} savePriority", this.getClass().getSimpleName(), e);
            throw e;
        }
    }

    @Override
    @Transactional(rollbackFor = RuntimeException.class)
    public void deletePriorityConfigList(List<StrategyPriorityGroupVO> dataList) throws Exception {
        if (CollectionUtils.isNotEmpty(dataList)) {
            for (StrategyPriorityGroupVO strategyPriorityGroupVO : dataList) {
                Integer groupId = strategyPriorityGroupVO.getGroupId();
                List<StrategyPriorityConfig> priorityConfigs = strategyPriorityGroupVO.getData();
                List<String> crossIds = strategyPriorityGroupVO.getCrossIds();
                String crossId = null;
                if (CollectionUtils.isNotEmpty(crossIds)) {
                    crossId = crossIds.get(0);
                }
                List<Integer> greenIds = strategyPriorityGroupVO.getGreenIds();
                Integer greenId = null;
                if (CollectionUtils.isNotEmpty(greenIds)) {
                    greenId = greenIds.get(0);
                }
                // 当全部删除时，1.校验日计划中是否有使用;2.并且删除数量=数据库中数量
                List<StrategyPriorityConfig> data4DB = strategyPriorityMapper.selectCrossGroupStrategyPriorityList(crossId, greenId, groupId);
                List<StrategyPriorityDailyInfo> dailyInfos = strategyPriorityMapper.selectCrossGreenGroupDailyPlanList(crossId, greenId, groupId);
                if (CollectionUtils.isEmpty(data4DB)) {
                    return;
                }
                if (CollectionUtils.isNotEmpty(dailyInfos) && data4DB.size() <= priorityConfigs.size()) {
                    throw new OptServiceException("日计划中已使用当前分组: " + groupId + " 不能清空！");
                }

                // 删除路口编号分组下策略编号
                if (CollectionUtils.isNotEmpty(priorityConfigs)) {
                    for (StrategyPriorityConfig priorityConfig : priorityConfigs) {
                        strategyPriorityMapper.deleteCrossGreenPriorityConfig(crossId, greenId, groupId, priorityConfig.getStrategyNo());
                    }
                }

            }
        }
    }

    /*
     * 策略优先级路口跟干线数据回显
     * */
    @Override
    @Transactional
    public List<StrategyFactoryEntity> getPriorityData(String crossId, Integer greenId, Integer type) throws Exception {

        try {
            List<StrategyFactoryEntity> priorityList = new ArrayList<>();
            //type: 1路口 2干线
            if (type == 1) {
                if (crossId.isEmpty()) {
                    throw new IllegalArgumentException("crossId cannot be null");
                }
                //先获取策略编号
                List<String> strategyNo = strategyPriorityMapper.getstrategyNo(crossId, type);
                if (CollectionUtils.isEmpty(strategyNo)) {
                    return Collections.emptyList();
                }
                priorityList = strategyPriorityMapper.getPriorityConfigData(strategyNo, crossId, type);

            } else if (type == 2) {
                if (greenId == null) {
                    throw new IllegalArgumentException("greenId cannot be null");
                }
                //先获取策略编号
                List<String> strategyNo = strategyPriorityMapper.getGreenstrategyNo(greenId, type);
                if (CollectionUtils.isEmpty(strategyNo)) {
                    return Collections.emptyList();
                }
                priorityList = strategyPriorityMapper.getGreenPriorityConfigData(strategyNo, greenId, type);
            }
            return priorityList;
        } catch (Exception e) {
            log.error("{} getPriorityData", this.getClass().getSimpleName(), e);
            throw e;
        }

    }

    /*
     * 策略管理日计划批量保存 干线跟路口
     * */
    @Override
    @Transactional
    public void savePlanConfig(List<StrategyPriorityGroupVO> dailyPlanDetails) throws Exception {

        try {
            List<StrategyPriorityDailyInfo> savePlanList = new ArrayList<>();
            ObjectMapper objectMapper = new ObjectMapper();
            for (StrategyPriorityGroupVO group : dailyPlanDetails) {
                //Type : 1;路口2：干线
                Integer typePd = group.getType();
                if (typePd == 1) {
                    //路口ID
                    List<String> crossList = group.getCrossIds();
                    //选中多个路口存多条数据
                    for (String crossId : crossList) {
                        StrategyPriorityDailyInfo strategyPriorityDailyInfo = new StrategyPriorityDailyInfo();
                        strategyPriorityDailyInfo.setCrossId(crossId);
                        //1；路口2干线
                        Integer type = group.getType();
                        strategyPriorityDailyInfo.setType(type);
                        //日计划编号
                        Integer dailyPlanId = group.getDailyPlanId();
                        strategyPriorityDailyInfo.setDailyPlanId(dailyPlanId);
                        //执行时间
                        String weekExecute = group.getWeekExecute();
                        strategyPriorityDailyInfo.setWeekExecute(weekExecute);
                        //先判断表里有没有数据，有的话删除t_strategy_priority_daily_info
                        List<StrategyPriorityDailyInfo> planConfig = strategyPriorityMapper.selectPlanTable(crossId);
                        if (planConfig.size() > 0) {
                            strategyPriorityMapper.deletePlanConfig(crossId);
                        }

                        //取出日计划详情
                        List<StrategyPriorityPlanDetails> dailyPlanDetails1 = group.getDailyPlanDetails();
                        if (CollectionUtils.isNotEmpty(dailyPlanDetails1)) {
                            dailyPlanDetails1.forEach(item -> {
                                StringBuilder sb = new StringBuilder();
                                List<StrategyFactoryEntity> factoryList = strategyPriorityMapper.selectCrossGroupStrategyList(crossId, null, item.getGroupId());
                                if (CollectionUtils.isNotEmpty(factoryList)) {
                                    for (StrategyFactoryEntity factory : factoryList) {
                                        sb.append(factory.getMethod()).append(",");
                                    }
                                    String content = sb.substring(0, sb.length() - 1);
                                    item.setContent(content);
                                }
                            });
                        }
                        String dailyPlanDetailsJson = JSON.toJSONString(dailyPlanDetails1);
                        strategyPriorityDailyInfo.setDailyPlanDetails(dailyPlanDetailsJson);

                        savePlanList.add(strategyPriorityDailyInfo);
                    }
                } else if (typePd == 2) {
                    //干线ID
                    List<Integer> greenIdList = group.getGreenIds();
                    //选中多个路口存多条数据
                    for (Integer greenId : greenIdList) {
                        StrategyPriorityDailyInfo strategyPriorityDailyInfo = new StrategyPriorityDailyInfo();
                        strategyPriorityDailyInfo.setGreenId(greenId);
                        //1；路口2干线
                        Integer type = group.getType();
                        strategyPriorityDailyInfo.setType(type);
                        //日计划编号
                        Integer dailyPlanId = group.getDailyPlanId();
                        strategyPriorityDailyInfo.setDailyPlanId(dailyPlanId);
                        //执行时间
                        String weekExecute = group.getWeekExecute();
                        strategyPriorityDailyInfo.setWeekExecute(weekExecute);
                        //先判断表里有没有数据，有的话删除t_strategy_priority_daily_info
                        List<StrategyPriorityDailyInfo> planConfig = strategyPriorityMapper.selectGreenPlanTable(greenId);
                        if (planConfig.size() > 0) {
                            strategyPriorityMapper.deleteGreenPlanConfig(greenId);
                        }

                        //取出日计划详情
                        List<StrategyPriorityPlanDetails> dailyPlanDetails1 = group.getDailyPlanDetails();
                        if (CollectionUtils.isNotEmpty(dailyPlanDetails1)) {
                            dailyPlanDetails1.forEach(item -> {
                                StringBuilder sb = new StringBuilder();
                                List<StrategyFactoryEntity> factoryList = strategyPriorityMapper.selectCrossGroupStrategyList(null, greenId, item.getGroupId());
                                if (CollectionUtils.isNotEmpty(factoryList)) {
                                    for (StrategyFactoryEntity factory : factoryList) {
                                        sb.append(factory.getMethod()).append(",");
                                    }
                                    String content = sb.substring(0, sb.length() - 1);
                                    item.setContent(content);
                                }
                            });
                        }
                        String dailyPlanDetailsJson = JSON.toJSONString(dailyPlanDetails1);
                        strategyPriorityDailyInfo.setDailyPlanDetails(dailyPlanDetailsJson);

                        savePlanList.add(strategyPriorityDailyInfo);
                    }
                }
            }
            strategyPriorityMapper.savePlanConfig(savePlanList);


            List<StrategyPriorityPlanPush> strategyPriorityPlanPush = pushStrategyPriorityPlan(dailyPlanDetails);
            //推送日计划配置到神思
            StrategyPriorityPlanPushReq req = new StrategyPriorityPlanPushReq();
            req.setData(strategyPriorityPlanPush);
            Result result = pushStrategyControlService.StartegyPriorityPlanPush(req);
        } catch (Exception e) {
            log.error("{} savePlanConfig", this.getClass().getSimpleName(), e);
            throw e;
        }
    }

    /*
     * 日计划回显接口
     * */
    @Override
    public List<StrategyPriorityDailyInfo> getPlanConfigData(String crossId, Integer greenId, Integer type) {

        //type: 1路口 2干线
        List<StrategyPriorityDailyInfo> planList = new ArrayList<>();
        if (type == 1) {
            if (crossId.isEmpty()) {
                throw new IllegalArgumentException("crossId cannot be null");
            }
            planList = strategyPriorityMapper.getPlanConfigData(crossId, type);
        } else if (type == 2) {
            if (greenId == null) {
                throw new IllegalArgumentException("greenId cannot be null");
            }
            planList = strategyPriorityMapper.getGreenPlanConfigData(greenId, type);
        }

        return planList;
    }

    /*
     *  策略参数配置干线路口
     * */
    @Override
    @Transactional
    public void saveParamterConfig(StrategyPriorityGroupVO group) throws Exception {

        try {
            List<StrategyParameterConfig> savePlanList = new ArrayList<>();
            //路口ID
            List<String> crossList = group.getCrossIds();
            //干线id
            List<Integer> greenIdList = group.getGreenIds();

            //Type : 1;路口2：干线
            Integer typePd = group.getType();
            if (typePd == 1) {
                //选中多个路口存多条数据
                for (String crossId : crossList) {
                    StrategyParameterConfig strategyParameterConfig = new StrategyParameterConfig();
                    //Type : 1;路口2：干线
                    Integer type = group.getType();
                    strategyParameterConfig.setType(type);
                    //策略编号
                    String strategyNo = group.getStrategyNo();
                    strategyParameterConfig.setStrategyNo(strategyNo);
                    //路口id
                    //String crossId = group.getCrossId();
                    strategyParameterConfig.setCrossId(crossId);
                    //先判断表里有没有数据，有的话删除t_strategy_priority_parameter
                    List<StrategyParameterConfig> paramterConfig = strategyPriorityMapper.paramterConfigTable(crossId);
                    if (paramterConfig.size() > 0) {
                        strategyPriorityMapper.deleteParamterConfig(crossId);
                    }
                    //参数 场景配置
                    List<StrategyPriorityParamter> parameterConfigList = group.getParameterConfigList();
                    String jsonString = JSON.toJSONString(parameterConfigList);
                    strategyParameterConfig.setParamDetails(jsonString);
                    //策略调度参数配置
                    StrategySchedulingParam schedulingParamters = group.getSchedulingParamters();
                    ObjectMapper objectMapper = new ObjectMapper();
                    String schedulingParamter = objectMapper.writeValueAsString(schedulingParamters);
                    strategyParameterConfig.setSchedulingParam(schedulingParamter);
                    //添加到最终数据
                    savePlanList.add(strategyParameterConfig);
                }
            } else if (typePd == 2) {
                for (Integer greenId : greenIdList) {
                    StrategyParameterConfig strategyParameterConfig = new StrategyParameterConfig();
                    //Type : 1;路口2：干线
                    Integer type = group.getType();
                    strategyParameterConfig.setType(type);
                    //策略编号
                    String strategyNo = group.getStrategyNo();
                    strategyParameterConfig.setStrategyNo(strategyNo);
                    //路口id
                    //String crossId = group.getCrossId();
                    strategyParameterConfig.setGreenId(greenId);
                    //先判断表里有没有数据，有的话删除t_strategy_priority_parameter
                    List<StrategyParameterConfig> paramterConfig = strategyPriorityMapper.paramterGreenConfigTable(greenId);
                    if (paramterConfig.size() > 0) {
                        strategyPriorityMapper.deleteGreenParamterConfig(greenId);
                    }
                    //参数 场景配置
                    List<StrategyPriorityParamter> parameterConfigList = group.getParameterConfigList();
                    String jsonString = JSON.toJSONString(parameterConfigList);
                    strategyParameterConfig.setParamDetails(jsonString);
                    //添加到最终数据
                    savePlanList.add(strategyParameterConfig);
                }

            }
            strategyPriorityMapper.saveParamConfig(savePlanList);

            //组装神思需要的参数配置接口
            List<StrategyParameterPush> strategyParameterPush = pushStrategyPriorityParam(group);
            //推送神思
            //Result result = pushStrategyControlService.StartegyPriorityParameterPush(strategyParameterPush);
        } catch (Exception e) {
            log.error("{} saveParamterConfig", this.getClass().getSimpleName(), e);
            throw e;
        }

    }

    /*
     *  策略参数配置干线路口数据回显
     * */
    @Override
    public List<StrategyParameterConfig> getParamConfigData(String crossId, Integer greenId, Integer type, String strategyNo) {
        try {
            List<StrategyParameterConfig> paraterConfigList = new ArrayList<>();
            //type: 1路口 2干线
            if (type == 1) {
                if (crossId.isEmpty()) {
                    throw new IllegalArgumentException("crossId cannot be null");
                }
                paraterConfigList = strategyPriorityMapper.getParamConfigData(crossId, type, strategyNo);
            } else if (type == 2) {
                if (greenId == null) {
                    throw new IllegalArgumentException("greenId cannot be null");
                }
                paraterConfigList = strategyPriorityMapper.getGreenParamConfigData(greenId, type, strategyNo);
            }
            return paraterConfigList;
        } catch (Exception e) {
            log.error("{} getParamConfigData", this.getClass().getSimpleName(), e);
            throw e;
        }

    }

    /*
     *  策略干线列表
     * */
    @Override
    public List<StrategyPriorityDailyInfo> getStrategyGreenWave() {

        try {
            List<StrategyPriorityDailyInfo> queryResult = strategyPriorityMapper.getStrategyGreenWave();

            Map<Integer, List<StrategyPriorityDailyInfo>> groupedData = queryResult.stream()
                    .collect(Collectors.groupingBy(StrategyPriorityDailyInfo::getGreenId));

            // 格式化输出
            List<StrategyPriorityDailyInfo> result = groupedData.entrySet().stream()
                    .map(entry -> {
                        //干线ID
                        int trunkId = entry.getKey();
                        List<StrategyPriorityDailyInfo> infos = entry.getValue();
                        // 创建新的对象
                        StrategyPriorityDailyInfo strategyPriorityDailyInfo = new StrategyPriorityDailyInfo();
                        // 提取干线名称（假设同一干线的名称相同）
                        String trunkName = infos.get(0).getWaveName();


                        // 按干线 ID 分组并合并日计划详情
                        Map<Integer, Set<String>> crossGroupedDetails = infos.stream()
                                .filter(info -> info.getDailyPlanDetails() != null)
                                .collect(Collectors.groupingBy(
                                        StrategyPriorityDailyInfo::getGreenId,
                                        Collectors.mapping(StrategyPriorityDailyInfo::getDailyPlanDetails, Collectors.toSet()))); // 去重

                        // 合并每个路口的日计划详情
                        String dailyPlanDetails = crossGroupedDetails.values().stream()
                                .map(set -> String.join(", ", set))
                                .collect(Collectors.joining(", "));
                        // 提取路口 ID 和路口名称
                        String roadIds = infos.stream()
                                .map(StrategyPriorityDailyInfo::getCrossId)
                                .collect(Collectors.joining(", "));
                        String roadNames = infos.stream()
                                .map(StrategyPriorityDailyInfo::getCrossName)
                                .collect(Collectors.joining(", "));
                        strategyPriorityDailyInfo.setGreenId(trunkId);
                        strategyPriorityDailyInfo.setWaveName(trunkName);
                        strategyPriorityDailyInfo.setCrossId(roadIds);
                        strategyPriorityDailyInfo.setCrossName(roadNames);
                        strategyPriorityDailyInfo.setDailyPlanDetails(dailyPlanDetails);
                        return strategyPriorityDailyInfo;
                    })
                    .collect(Collectors.toList());
            // 输出结果
            return result;
        } catch (Exception e) {
            log.error("{} getStrategyGreenWave", this.getClass().getSimpleName(), e);
            throw e;
        }

    }

    /*优先级配置神思推送*/
//	private List<StrategyPriorityConfigPush> pushStrategyPriorityConfig(List<StrategyPriorityGroup> dataList) {
//		//最终优先级配置推送神思
//		List<StrategyPriorityConfigPush> pushStrategyPriorityList = new ArrayList<>();
//
//		for  (StrategyPriorityGroup group : dataList) {
//			// 创建顶层对象
//			StrategyPriorityConfigPush strategyPriorityConfigPush = new StrategyPriorityConfigPush();
//			//1:路口 2：干线
//			Integer type = group.getType();
//			if (type==1){
//				//路口ID
//				List<String> crossIds = group.getCrossIds();
//				strategyPriorityConfigPush.setCrossId(crossIds);
//				//干线ID
//				List<Integer> greenIds = group.getGreenIds();
//				strategyPriorityConfigPush.setGreenId(null);
//				//type
//				strategyPriorityConfigPush.setType(type);
//
//				// 组装分组详情
//				List<GroupIdDetails> groupIdDetailsList = new ArrayList<>();
//				GroupIdDetails groupIdDetails = new GroupIdDetails();
//				//分组名称
//				String label = group.getLabel();
//				//分组编号
//				Integer labelCode = group.getLabelCode();
//				groupIdDetails.setGroupId(labelCode);
//				groupIdDetails.setGroupName(label);
//				// 创建一个临时列表，用于存储所有详情数据
//				List<StrategyPriorityDetailsPush> detailsList = new ArrayList<>();
//				//组装详情数据
//				for (StrategyPriorityConfig item : group.getData()) {
//					StrategyPriorityDetailsPush strategyPriorityDetailsPush=new StrategyPriorityDetailsPush();
//					//策略编号
//					strategyPriorityDetailsPush.setStrategyNo(item.getStrategyNo());
//					//策略名称
//					strategyPriorityDetailsPush.setStrategyName(item.getStrategyName());
//					//优先级
//					strategyPriorityDetailsPush.setPriority(item.getPriority());
//					//场景名称
//					strategyPriorityDetailsPush.setMethod(item.getMethod());
//					//场景编码
//					strategyPriorityDetailsPush.setScene(item.getScene());
//					//公司名称
//					strategyPriorityDetailsPush.setCompany(item.getCompany());
//					// 将详情数据添加到临时列表中
//					detailsList.add(strategyPriorityDetailsPush);
//				}
//				//设置详情数据
//				groupIdDetails.setStrategyDetails(detailsList);
//
//				groupIdDetailsList.add(groupIdDetails);
//				strategyPriorityConfigPush.setGroupIdDetails(groupIdDetailsList);
//				// 将组装好的 StrategyPriorityConfigPush 对象添加到最终列表中
//				pushStrategyPriorityList.add(strategyPriorityConfigPush);
//
//			}else if (type==2){
//				//干线ID
//				List<Integer> greenIds = group.getGreenIds();
//				strategyPriorityConfigPush.setGreenId(greenIds);
//				strategyPriorityConfigPush.setType(type);
//				//路口ID
//				List<String> crossIds = group.getCrossIds();
//				strategyPriorityConfigPush.setCrossId(null);
//				// 组装分组详情
//				List<GroupIdDetails> groupIdDetailsList = new ArrayList<>();
//				GroupIdDetails groupIdDetails = new GroupIdDetails();
//				//分组名称
//				String label = group.getLabel();
//				//分组编号
//				Integer labelCode = group.getLabelCode();
//				groupIdDetails.setGroupId(labelCode);
//				groupIdDetails.setGroupName(label);
//				// 创建一个临时列表，用于存储所有详情数据
//				List<StrategyPriorityDetailsPush> detailsList = new ArrayList<>();
//				//组装详情数据
//				for (StrategyPriorityConfig item : group.getData()) {
//					StrategyPriorityDetailsPush strategyPriorityDetailsPush=new StrategyPriorityDetailsPush();
//					//策略编号
//					strategyPriorityDetailsPush.setStrategyNo(item.getStrategyNo());
//					//策略名称
//					strategyPriorityDetailsPush.setStrategyName(item.getStrategyName());
//					//优先级
//					strategyPriorityDetailsPush.setPriority(item.getPriority());
//					//场景名称
//					strategyPriorityDetailsPush.setMethod(item.getMethod());
//					//场景编码
//					strategyPriorityDetailsPush.setScene(item.getScene());
//					//公司名称
//					strategyPriorityDetailsPush.setCompany(item.getCompany());
//					// 将详情数据添加到临时列表中
//					detailsList.add(strategyPriorityDetailsPush);
//				}
//				//设置详情数据
//				groupIdDetails.setStrategyDetails(detailsList);
//
//				groupIdDetailsList.add(groupIdDetails);
//				strategyPriorityConfigPush.setGroupIdDetails(groupIdDetailsList);
//				// 将组装好的 StrategyPriorityConfigPush 对象添加到最终列表中
//				pushStrategyPriorityList.add(strategyPriorityConfigPush);
//			}
//		}
//		return pushStrategyPriorityList;
//	}
    /*优先级配置神思推送*/
    private List<StrategyPriorityConfigPush> pushStrategyPriorityConfig(List<StrategyPriorityGroupVO> dataList) {

        // 最终优先级配置推送神思
        List<StrategyPriorityConfigPush> pushStrategyPriorityList = new ArrayList<>();
        // 创建顶层对象
        StrategyPriorityConfigPush strategyPriorityConfigPush = new StrategyPriorityConfigPush();
        // 分组详情列表
        List<GroupIdDetails> groupIdDetailsList = new ArrayList<>();
        for (StrategyPriorityGroupVO group : dataList) {

            // 设置基本信息
            Integer type = group.getType();
            strategyPriorityConfigPush.setType(type);

            if (type == 1) {
                // 路口类型
                strategyPriorityConfigPush.setCrossId(group.getCrossIds());
                strategyPriorityConfigPush.setGreenId(null);
            } else if (type == 2) {
                // 干线类型
                strategyPriorityConfigPush.setGreenId(group.getGreenIds());
                strategyPriorityConfigPush.setCrossId(null);
            }

            GroupIdDetails groupIdDetails = new GroupIdDetails();
            // 设置分组名称和编号
            groupIdDetails.setGroupName(group.getGroupName());
            groupIdDetails.setGroupId(group.getGroupId());

            // 创建一个临时列表，用于存储所有策略详情数据
            List<StrategyPriorityDetailsPush> detailsList = new ArrayList<>();

            // 组装策略详情数据
            for (StrategyPriorityConfig item : group.getData()) {
                StrategyPriorityDetailsPush strategyPriorityDetailsPush = new StrategyPriorityDetailsPush();
                // 填充策略详情字段
                //策略编号
                strategyPriorityDetailsPush.setStrategyNo(item.getStrategyNo());
                //策略名称
                strategyPriorityDetailsPush.setStrategyName(item.getStrategyName());
                //优先级
                strategyPriorityDetailsPush.setPriority(item.getPriority());
                //场景名称
                strategyPriorityDetailsPush.setMethod(item.getMethod());
                //场景编码
                strategyPriorityDetailsPush.setScene(item.getScene());
                //公司名称
                strategyPriorityDetailsPush.setCompany(item.getCompany());

                // 将策略详情添加到临时列表中
                detailsList.add(strategyPriorityDetailsPush);
            }
            // 设置策略详情列表
            groupIdDetails.setStrategyDetails(detailsList);
            // 添加分组详情到分组详情列表
            groupIdDetailsList.add(groupIdDetails);
        }
        // 设置分组详情列表到顶层对象
        strategyPriorityConfigPush.setGroupIdDetails(groupIdDetailsList);

        // 将组装好的 StrategyPriorityConfigPush 对象添加到最终列表中

        pushStrategyPriorityList.add(strategyPriorityConfigPush);

        return pushStrategyPriorityList;
    }

    /*日计划配置神思推送*/
    private List<StrategyPriorityPlanPush> pushStrategyPriorityPlan(List<StrategyPriorityGroupVO> dailyPlanDetails) {

        //日计划推送到神思
        List<StrategyPriorityPlanPush> strategyPriorityPlanPushList = new ArrayList<>();
        StrategyPriorityPlanPush strategyPriorityPlanPush = new StrategyPriorityPlanPush();
        //
        List<DailyPlanDetails> dailyPlanDetailsList = new ArrayList<>();
        for (StrategyPriorityGroupVO group : dailyPlanDetails) {

            Integer type = group.getType();
            strategyPriorityPlanPush.setType(type);
            //1:路口 2干线
            if (type == 1) {
                List<String> crossIds = group.getCrossIds();
                strategyPriorityPlanPush.setCrossId(crossIds);
                strategyPriorityPlanPush.setGreenId(null);
            } else {
                List<Integer> greenIds = group.getGreenIds();
                strategyPriorityPlanPush.setCrossId(null);
                strategyPriorityPlanPush.setGreenId(greenIds);
            }
            DailyPlanDetails dailyPlanDetailsPush = new DailyPlanDetails();
            //日计划编号
            Integer dailyPlanId = group.getDailyPlanId();
            //执行时间
            String weekExecuteStr = group.getWeekExecute();
            List<String> weekExecutelist = Arrays.asList(weekExecuteStr);
            //日计划编号
            dailyPlanDetailsPush.setDailyPlanId(dailyPlanId);
            //执行时间
            List<Integer> weeks = new ArrayList<>();
            if (StringUtils.isNotBlank(weekExecuteStr)) {
                String[] split = weekExecuteStr.split(",");
                for (String s : split) {
                    weeks.add(Integer.valueOf(s));
                }
            }
            dailyPlanDetailsPush.setWeekExecute(weeks);

            // 时间详情临时储存
            List<TimePlanDetails> timePlanDetailsList = new ArrayList<>();
            //取出日计划详情
            List<StrategyPriorityPlanDetails> dailyPlanDetailList = group.getDailyPlanDetails();
            for (StrategyPriorityPlanDetails item : dailyPlanDetailList) {
                TimePlanDetails timePlanDetails = new TimePlanDetails();
                //分组编号
                timePlanDetails.setGroupId(item.getGroupId());
                //执行时段
                timePlanDetails.setTimes(item.getTimes());
                timePlanDetailsList.add(timePlanDetails);
            }

            dailyPlanDetailsPush.setTimeDetails(timePlanDetailsList);
            // 将每日计划详情添加到列表
            dailyPlanDetailsList.add(dailyPlanDetailsPush);
        }
        // 设置每日计划详情列表到推送对象
        strategyPriorityPlanPush.setDailyPlanDetails(dailyPlanDetailsList);

        strategyPriorityPlanPushList.add(strategyPriorityPlanPush);
        return strategyPriorityPlanPushList;
    }

    /*参数配置神思推送*/
    private List<StrategyParameterPush> pushStrategyPriorityParam(StrategyPriorityGroupVO group) {
        List<StrategyParameterPush> StrategyParameterPushList = new ArrayList<>();
        //推送神思接口
        StrategyParameterPush strategyParameterPush = new StrategyParameterPush();
        //类型:1路口 2 干线
        Integer type = group.getType();
        //路口id
        List<String> crossIds = group.getCrossIds();
        //干线id
        List<Integer> greenIds = group.getGreenIds();
        //策略编号
        String strategyNo = group.getStrategyNo();
        //策略名称
        String strategyName = group.getStrategyName();
        //场景编号
        Integer scene = group.getScene();
        //场景名称
        String method = group.getMethod();
        //1 路口 2干线
        if (type == 1) {
            strategyParameterPush.setType(1);
            strategyParameterPush.setGreenId(null);
            strategyParameterPush.setCrossId(crossIds);
        } else {
            strategyParameterPush.setType(2);
            strategyParameterPush.setGreenId(greenIds);
            strategyParameterPush.setCrossId(null);
        }
        strategyParameterPush.setStrategyNo(strategyNo);
        strategyParameterPush.setStrategyName(strategyName);
        strategyParameterPush.setScene(scene);
        strategyParameterPush.setMethod(method);

        //参数详情
        List<StrategyParamDetailsPush> strategyParamDetailsList = new ArrayList<>();
        //参数详情
        List<StrategyPriorityParamter> parameterConfigList = group.getParameterConfigList();
        for (StrategyPriorityParamter item : parameterConfigList) {
            StrategyParamDetailsPush strategyParamDetailsPush = new StrategyParamDetailsPush();
            strategyParamDetailsPush.setParamEN(item.getParamEN());
            strategyParamDetailsPush.setParamCN(item.getParamCN());
            strategyParamDetailsPush.setDescription(item.getDescription());
            strategyParamDetailsPush.setDataType(item.getDataType());
            strategyParamDetailsPush.setThreshold(item.getThreshold());
            strategyParamDetailsPush.setValue(item.getValue());
            strategyParamDetailsList.add(strategyParamDetailsPush);
        }
        strategyParameterPush.setParamDetails(strategyParamDetailsList);
        if (type == 1) {
            //取出调度详情
            StrategySchedulingParam schedulingParamters = group.getSchedulingParamters();
            List<StrategySchedulingItem> start = schedulingParamters.getStart();
            List<StrategySchedulingItem> end = schedulingParamters.getEnd();
            //组装调度详情
            SchedulingParamPush schedulingParamPush = new SchedulingParamPush();
            schedulingParamPush.setStart(start);
            schedulingParamPush.setEnd(end);
            strategyParameterPush.setSchedulingParam(schedulingParamPush);
        } else {
            strategyParameterPush.setSchedulingParam(null);
        }
        StrategyParameterPushList.add(strategyParameterPush);
        return StrategyParameterPushList;
    }

}
